@@ -1,10 +1,13 @@
 from typing import *
 import asyncio
 from starlette.applications import Starlette
-from starlette.routing import Route, Mount
+from starlette.routing import Mount
 from starlette.staticfiles import StaticFiles
+from starlette.middleware import Middleware
+from starlette.exceptions import ExceptionMiddleware
 
 from . import run, config, requests, logger, ds, runtime, middlewares, ui
+from .requests import Route
 
 
 def get_default_path() -> str:
@@ -51,22 +54,26 @@ async def start():
 
 # The place where ASGI about to be prepared to start
 
+_middlewares: List[Middleware] = middlewares.registered + [
+    Middleware(ExceptionMiddleware)
+]
+
 logger.debug(
-    "middlewares in use (ordered):\n" + '\n'.join(["  %s" % str(m) for m in middlewares.registered])
+    "middlewares in use (ordered):\n" + '\n'.join(["  %s" % str(m) for m in _middlewares])
 )
 
 
-_routes: List[Union[Route, Mount]] = requests.routing.registered
-_routes.insert(0, requests.Route('/', root_route, methods=['GET']))
+_routes: List[Union[requests.Route, Mount]] = requests.routing.registered
+_routes.insert(0, Route('/', root_route, methods=['GET']))
 _routes.append(Route(config.URL['login_screen'], ui.screens.Screen.endpoint, methods=['GET']))
 _routes.append(Mount(config.STATICS_URL, app=StaticFiles(directory=config.STATICS_ROOT), name='static'))
-_routes.append(requests.Route('/{rest_of_path:path}', default_route, methods=['GET']))
+_routes.append(Route('/{rest_of_path:path}', default_route, methods=['GET']))
 
 
 # Creating the ASGI actual instance
 asgi = Starlette(
     on_startup=[start],
-    middleware=middlewares.registered,
+    middleware=_middlewares,
     routes=_routes,
     debug=False
 )
