@@ -5,7 +5,7 @@ from sqlalchemy.ext.hybrid import *
 from . import engine, db, migrate
 from .db import *
 from .model import *
-from .model import OrmModel as Model
+from .model import DatabaseModel as Model
 from .reg import *
 from .types import *
 from .helpers import *
