@@ -7,18 +7,24 @@ from ..runtime import context
 __all__ = [
     'create_connection',
     'get_connection',
-    'close_connection',
-    'RedisConnection'
+    # 'close_connection',
+    'RedisConnection',
+    'pool',
+    'disconnect'
 ]
 
 
+pool: aioredis.ConnectionPool = aioredis.ConnectionPool.from_url(
+    config.REDIS['uri'],
+    password=config.REDIS['password'],
+    encoding='utf-8'
+)
+
+
 async def create_connection() -> RedisConnection:
     """ Makes a new connection to the REDIS database and returns connection to the caller. """
-    return aioredis.from_url(
-        config.REDIS['uri'],
-        password=config.REDIS['password'],
-        encoding='utf-8'
-    )
+
+    return RedisConnection(connection_pool=pool)
 
 
 async def get_connection() -> RedisConnection:
@@ -32,12 +38,17 @@ async def get_connection() -> RedisConnection:
     return context['redis']
 
 
-async def close_connection(connection: RedisConnection = None) -> None:
+async def disconnect() -> None:
+    await pool.disconnect()
 
-    if not connection:
-        if 'redis' not in context:
-            return
-        connection = context['redis']
 
-    await connection.close()
+# async def close_connection(connection: RedisConnection = None) -> None:
+#
+#     if not connection:
+#         if 'redis' not in context:
+#             return
+#         connection = context['redis']
+#
+#     await connection.disconnect()
+#     await connection.close()
 
