@@ -8,6 +8,7 @@ import {
   ImageList,
   ImageListItem,
   ImageListItemBar,
+  ImageView,
   MaterialIcon,
   Tooltip,
   Typography
@@ -26,9 +27,12 @@ export type StoredImagesListProps = {
   apiEntity: string
   storageEntity: string
   columns?: number
+  dropAndDropUpload?: boolean
   rowHeight?: 'auto' | number
   gap?: number
-  permitDelete?: boolean
+  minHeight?: any               /** Used mainly for drag&drop facility on full page height */
+  multipleUpload?: boolean      /** Permit several new files to be uploaded at one time */
+  permitDelete?: boolean        /** Permit deletion of existing (uploaded) files */
   permitEdit?: boolean
   permitUpload?: boolean
   permitRearrange?: boolean
@@ -41,6 +45,7 @@ type StoredImagesListState = {
   items: StoredImagesModel,
   selected: number[]
   rearrangeMode: boolean
+  opened: string
 }
 
 
@@ -52,7 +57,8 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
     loading: true,
     items: [],
     selected: [],
-    rearrangeMode: false
+    rearrangeMode: false,
+    opened: ''
   }
 
   replacingId: number | null
@@ -62,7 +68,8 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
     this.replacingId = null
   }
 
-  private fileinput: React.RefObject<HTMLInputElement> = React.createRef()
+  private uploadFileInput: React.RefObject<HTMLInputElement> = React.createRef()
+  private replaceFileInput: React.RefObject<HTMLInputElement> = React.createRef()
 
   componentDidMount() {
     this.load()
@@ -71,7 +78,7 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
   public load = (): void => {
     const path: RequestApiPath = this.requestPath()
     api.get(path).then(res => {
-      const items: StoredImagesModel = res.data
+      const items: StoredImagesModel = res.data.filter((item: StoredImageModel) => item.file !== null)
       const ids: number[] = items.map((el: StoredImageModel) => el.id)
       const selected: number[] = this.state.selected.filter((el: number) => ids.includes(el))
       this.setState({
@@ -145,14 +152,15 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
     })
   }
 
-  private upload = (data: any): void => {
+  public upload = (files: any[]): void => {
     const form: FormData = new FormData()
-    if (data.target.files.length > 1) {
-      data.target.files.forEach((file: any, index: number) => {
-        form.append(`file${index}`, file)
+    if (files.length > 1) {
+      form.append('isMultipleFileUpload', 'true')
+      Array.from(files).forEach((file: any, index: number) => {
+        form.append(`fileUploadData_${index}`, file)
       })
     } else {
-      form.append('file', data.target.files[0])
+      form.append('fileUploadData', files[0])
     }
     runtime.setBusy()
 
@@ -178,6 +186,10 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
     }
   }
 
+  private uploadFromInput = (fileInputData: any): void => {
+    this.upload(Array.from(fileInputData.target.files))
+  }
+
   public renameFile = (id: number, caption: string): void => {
     runtime.setBusy()
     api.put(this.requestPath(id), {caption}).then(() => {
@@ -192,7 +204,54 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
 
   private selectFileForUpload = (id?: number): void => {
     this.replacingId = id || null
-    this.fileinput.current?.click()
+    if (this.replacingId === null) {
+      this.uploadFileInput.current?.click()
+    } else {
+      this.replaceFileInput.current?.click()
+    }
+  }
+
+  private handleSelectAll = (): void => {
+    const selected: number[] = []
+    this.state.items
+      .filter((item: StoredImageModel) => item.file !== null)
+      .forEach((item: StoredImageModel) => {
+        if (!this.state.selected.includes(item.id)) {
+          selected.push(item.id)
+        }
+      })
+    this.setState({selected})
+  }
+
+  private handleDragEnter = (ev: React.MouseEvent): void => {
+    ev.preventDefault()
+    ev.stopPropagation()
+  }
+
+  private handleDragOver = (ev: React.MouseEvent): void => {
+    ev.preventDefault()
+    ev.stopPropagation()
+  }
+
+  private handleDragDrop = (ev: React.DragEvent): void => {
+    ev.preventDefault()
+    ev.stopPropagation()
+    if (!(this.props.dropAndDropUpload ?? true))
+      return
+
+    let files: any[] = []
+
+    if (ev.dataTransfer.items) {
+      for (let i = 0; i < ev.dataTransfer.items.length; i++) {
+        if (ev.dataTransfer.items[i].kind !== 'file')
+          continue
+        files.push(ev.dataTransfer.items[i].getAsFile())
+      }
+    } else {
+      files = Array.from(ev.dataTransfer.files)
+    }
+
+    this.upload(files)
   }
 
   render() {
@@ -205,20 +264,65 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
 
     if (!this.state.items.length)
       return (
-        <Box pt={3} pb={3} borderTop={'1px solid #aaa'} borderBottom={'1px solid #aaa'}>
-          <Typography>{gettext("There are no files uploaded yet.", 'system.ui')}</Typography>
+        <Box
+          minHeight={this.props.minHeight}
+          onDragEnter={this.handleDragEnter}
+          onDragOver={this.handleDragOver}
+          onDrop={this.handleDragDrop}
+        >
+          <Box pt={3} pb={3} mb={2} borderTop={'1px solid #aaa'} borderBottom={'1px solid #aaa'}>
+            <Typography>{gettext("There are no files uploaded yet.", 'system.ui')}</Typography>
+          </Box>
+          {(this.props.permitUpload ?? true) && (
+            <Box display={'flex'} justifyContent={'flex-end'} alignItems={'center'}>
+              <input
+                type={'file'}
+                ref={this.uploadFileInput}
+                style={{display: 'none'}}
+                onChange={this.uploadFromInput}
+                multiple={this.props.multipleUpload ?? true}
+              />
+              <Tooltip title={gettext("Upload new image", 'system.ui')}>
+                <Button
+                  color={'primary'}
+                  variant={'outlined'}
+                  startIcon={<MaterialIcon icon={'publish'} />}
+                  style={{
+                    marginLeft: '8px'
+                  }}
+                  onClick={() => this.selectFileForUpload()}
+                >
+                  {gettext("Upload", 'system.ui')}
+                </Button>
+              </Tooltip>
+            </Box>
+          )}
         </Box>
       )
 
     return (
-      <Box>
+      <Box
+        minHeight={this.props.minHeight}
+        onDragEnter={this.handleDragEnter}
+        onDragOver={this.handleDragOver}
+        onDrop={this.handleDragDrop}
+      >
         {((this.props.permitUpload ?? true) || (this.props.permitEdit ?? true)) && (
-          <input
-            type={'file'}
-            ref={this.fileinput}
-            style={{display: 'none'}}
-            onChange={this.upload}
-          />
+          <React.Fragment>
+            <input
+              type={'file'}
+              ref={this.uploadFileInput}
+              style={{display: 'none'}}
+              onChange={this.uploadFromInput}
+              multiple={this.props.multipleUpload ?? true}
+            />
+            <input
+              type={'file'}
+              ref={this.replaceFileInput}
+              style={{display: 'none'}}
+              onChange={this.uploadFromInput}
+            />
+          </React.Fragment>
         )}
 
         {((this.props.permitUpload ?? true)
@@ -227,20 +331,31 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
         ) && (
           <Box display={'flex'} justifyContent={'flex-end'} alignItems={'center'}>
             {(this.props.permitDelete ?? true) && (!this.state.rearrangeMode) && (
-              <Tooltip title={gettext("Delete selected files")}>
-                <IconButton
-                  color={'secondary'}
-                  disabled={!this.state.selected.length}
-                  onClick={() => {
-                    this.removeFiles()
-                  }}
-                >
-                  <MaterialIcon icon={'delete_outline'} />
-                </IconButton>
-              </Tooltip>
+              <React.Fragment>
+                <Box flexGrow={1}>
+                  <Tooltip title={gettext("Select all")}>
+                    <IconButton
+                      onClick={this.handleSelectAll}
+                    >
+                      <MaterialIcon icon={'select_all'} />
+                    </IconButton>
+                  </Tooltip>
+                </Box>
+                <Tooltip title={gettext("Delete selected files")}>
+                  <IconButton
+                    color={'secondary'}
+                    disabled={!this.state.selected.length}
+                    onClick={() => {
+                      this.removeFiles()
+                    }}
+                  >
+                    <MaterialIcon icon={'delete_outline'} />
+                  </IconButton>
+                </Tooltip>
+              </React.Fragment>
             )}
             {(this.props.permitUpload ?? true) && (!this.state.rearrangeMode) && (
-              <Tooltip title={gettext("Delete selected files")}>
+              <Tooltip title={gettext("Upload new images", 'system.ui')}>
                 <Button
                   color={'primary'}
                   variant={'outlined'}
@@ -281,7 +396,9 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
         )}
 
         <ImageList cols={this.props.columns} gap={this.props.gap ?? 4} rowHeight={this.props.rowHeight} variant={'quilted'}>
-          {this.state.items.map((item: StoredImageModel, index: number, arr: any[]) => {
+          {this.state.items
+              .filter((item: StoredImageModel) => item.file !== null)
+              .map((item: StoredImageModel, index: number, arr: any[]) => {
             const showControls: boolean = this.state.rearrangeMode || (this.props.showControls !== undefined
                 ? Boolean(this.props.showControls)
                 : (this.props.permitDelete ?? true)
@@ -289,13 +406,23 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
 
             return (
               <ImageListItem>
-                <img src={storage.urlFor(this.props.storageEntity, item.file)} alt={item.caption} />
+                <img
+                  src={storage.urlFor(this.props.storageEntity, item.file)}
+                  alt={item.caption}
+                  onClick={(ev: React.MouseEvent) => {
+                    if ((ev.target as HTMLElement).tagName.toUpperCase() !== 'IMG')
+                      return
+                    this.setState({opened: storage.urlFor(this.props.storageEntity, item.file)})
+                  }}
+                />
+
                 {(this.props.showCaption ?? true) && item.caption !== undefined && item.caption !== '' && (
                   <ImageListItemBar
                     position={'bottom'}
                     title={item.caption}
                   />
                 )}
+
                 {showControls && (
                   <ImageListItemBar
                     position={'top'}
@@ -431,6 +558,11 @@ export class StoredImagesList extends React.Component<StoredImagesListProps, Sto
           })}
         </ImageList>
 
+        <ImageView
+          src={this.state.opened}
+          open={this.state.opened !== ''}
+          onClose={() => this.setState({opened: ''})}
+        />
       </Box>
     )
   }
