@@ -11,20 +11,82 @@ import {
   MaterialIcon,
   Toolbar
 } from 'system/components'
-import {LayoutAppbar} from '../LayoutAppbar'
+import LayoutAppbar from '../LayoutAppbar'
 import {Link} from 'react-router-dom'
 import {runtime} from 'system/runtime'
-import {screensSchema} from 'build/screens'
 import {routing} from 'system/routing'
-import './index.css'
 import {dialog} from 'system/dialog'
 import {messages, StoredMessage} from 'system/messages'
+import {SidebarItemModel} from 'system/types'
+import './index.css'
 
 
-type TSidebarFolderOpen = Record<string, boolean>
+type SidebarFolderOpenState = Record<string, boolean>
 type LayoutSidebarProps = { }
 type LayoutSidebarState = {
-  expandStatus: TSidebarFolderOpen
+  expandStatus: SidebarFolderOpenState
+}
+
+
+type SidebarItemProps = {
+  item: SidebarItemModel
+}
+
+
+const SidebarItemInner = (props: SidebarItemProps) => (
+  <ListItem
+    button
+    key={props.item.name}
+    data-key={props.item.name}
+    style={{
+      backgroundColor: 'inherit'
+    }}
+    onClick={() => {
+      if (props.item.endpoint === null)
+        return
+      // reserved for the future use with custom endpoint
+    }}
+  >
+    <ListItemIcon>
+      {props.item.icon !== null && (
+        <img
+          className={'SystemUI-LayoutSidebar-icon'}
+          src={props.item.icon}
+        />
+      )}
+    </ListItemIcon>
+    <ListItemText primary={props.item.caption}/>
+  </ListItem>
+)
+
+
+const SidebarItem = (props: SidebarItemProps) => {
+  const item: SidebarItemModel = props.item
+  if (!item.url)
+    return null  // at this moment - endpoint are not supported
+
+  switch (item.urlTarget) {
+    case 'container':
+      return null
+    case 'screen':
+      return (
+        <Link to={item.url} className={'SystemUI-LayoutSidebar-item'}>
+          <SidebarItemInner item={item} />
+        </Link>
+      )
+    case 'redirect':
+      return (
+        <a href={item.url} target={'_self'} className={'SystemUI-LayoutSidebar-item'}>
+          <SidebarItemInner item={item} />
+        </a>
+      )
+    default:  // blank
+      return (
+        <a href={item.url} target={'_blank'} className={'SystemUI-LayoutSidebar-item'}>
+          <SidebarItemInner item={item} />
+        </a>
+      )
+  }
 }
 
 
@@ -34,13 +96,13 @@ class Sidebar extends React.Component<LayoutSidebarProps, LayoutSidebarState> {
   }
 
   componentDidMount() {
-    const expandStatus: TSidebarFolderOpen = JSON.parse(localStorage.getItem('sidebarExpandStatus') || '{}')
+    const expandStatus: SidebarFolderOpenState = JSON.parse(localStorage.getItem('sidebarExpandStatus') || '{}')
     this.setState({expandStatus})
   }
 
   handleSidebarFolderClick = (event: React.MouseEvent<HTMLElement>) => {
     const key: string = String(event.currentTarget.dataset.key)
-    const expandStatus: TSidebarFolderOpen = this.state.expandStatus
+    const expandStatus: SidebarFolderOpenState = this.state.expandStatus
     if (typeof expandStatus[key] === 'undefined') {
       expandStatus[key] = true
     } else {
@@ -65,9 +127,9 @@ class Sidebar extends React.Component<LayoutSidebarProps, LayoutSidebarState> {
 
         <Box className={'SystemUI-LayoutSidebar-container'}>
           <List>
-            {runtime.sitemap.map(item => (
+            {runtime.sidebar.map(item => (
               <Box key={`sidebar-item-${item.name}`}>
-                {item.children !== null && item.children?.length > 0 && (
+                {(item.children != null && item.children?.length > 0) ? (
                   <React.Fragment>
                     <ListItem
                       button
@@ -99,54 +161,14 @@ class Sidebar extends React.Component<LayoutSidebarProps, LayoutSidebarState> {
                     >
                       <List component="div" disablePadding>
                         {item.children.map(child => (
-                          <Link to={screensSchema[child.screen]?.routeUrl} className={'SystemUI-LayoutSidebar-item'}>
-                            <ListItem
-                                button
-                                key={child.name}
-                                data-key={child.name}
-                                dense
-                                style={{
-                                  backgroundColor: 'inherit'
-                                }}
-                            >
-                              <ListItemIcon>
-                                {child.icon !== null && (
-                                  <img
-                                    className={'SystemUI-LayoutSidebar-icon'}
-                                    src={child.icon}
-                                  />
-                                )}
-                              </ListItemIcon>
-                              <ListItemText primary={child.caption}/>
-                            </ListItem>
-                          </Link>
+                          <SidebarItem item={child} />
                         ))}
                       </List>
                     </Collapse>
                   </React.Fragment>
-                )}
-                {item.children === null && (
-                  <Link to={screensSchema[item.screen]?.routeUrl} className={'SystemUI-LayoutSidebar-item'}>
-                    <ListItem
-                      button
-                      key={item.name}
-                      data-key={item.name}
-                      style={{
-                        backgroundColor: 'inherit'
-                      }}
-                    >
-                      <ListItemIcon>
-                        {item.icon !== null && (
-                          <img
-                            className={'SystemUI-LayoutSidebar-icon'}
-                            src={item.icon}
-                          />
-                        )}
-                      </ListItemIcon>
-                      <ListItemText primary={item.caption}/>
-                    </ListItem>
-                  </Link>
-                )}
+                ) : item.children === null ? (
+                  <SidebarItem item={item} />
+                ) : null}
               </Box>
             ))}
 
@@ -218,4 +240,5 @@ class Sidebar extends React.Component<LayoutSidebarProps, LayoutSidebarState> {
 }
 
 
-export const LayoutSidebar = observer(Sidebar)
+const LayoutSidebar = observer(Sidebar)
+export default LayoutSidebar
