@@ -23,13 +23,14 @@ export default class Screen extends React.Component<ScreenProps, ScreenState> {
     return (
       <React.Fragment>
         <Box mt={1}>
-          <Typography variant={'h4'}>{screenCaption || 'Images'}</Typography>
+          <Typography variant={'h4'} paddingBottom={2}>{screenCaption || 'Images'}</Typography>
         </Box>
         <Box>
           <StoredImagesList
             apiEntity={this.props.params['apiEntity']}
             storageEntity={this.props.params['storageEntity']}
             columns={this.props.params.columns}
+            minHeight={'calc(100vh - 72px)'}
             rowHeight={this.props.params.rowHeight}
             gap={this.props.params.gap}
           />
