@@ -1,5 +1,5 @@
 import {Response} from './response'
-import {IProjectInstantiation} from './types'
+import {ProjectConfiguration} from './types'
 import {api} from './api'
 import {RequestApiPath} from './routing'
 
@@ -8,11 +8,11 @@ const instantiatePath: RequestApiPath = api.path('system', 'instantiate')
 
 
 export type ProjectAppProvider = {
-  instantiate(): Response<IProjectInstantiation>
+  instantiate(): Response<ProjectConfiguration>
 }
 
 export const projectProvider: ProjectAppProvider = {
-  instantiate(): Response<IProjectInstantiation> {
+  instantiate(): Response<ProjectConfiguration> {
     return api.get(instantiatePath)
   }
 }
